//
//  RowColumnReversedDataSourceHelper.m
//  Sample
//
//  Created by Darrell Kress on 1/13/14.
//  Copyright (c) 2014 Infragistics. All rights reserved.
//

#import "RowColumnReversedDataSourceHelper.h"
#import <IG/IG.h>
#import "igSalesmanItem.h"

@implementation RowColumnReversedDataSourceHelper

// the number of columns in this case will be the number of rows for a normal grid (since we are flipping the two).
-(NSInteger)numberOfColumnsInGridView:(IGGridView *)gridView
{
    return [super gridView:gridView numberOfRowsInSection:0];
}
// And similarly the nubmer of rows in this case will be the number of columns in a normal grid
-(NSInteger)gridView:(IGGridView *)gridView numberOfRowsInSection:(NSInteger)section
{
    return [super numberOfColumnsInGridView:gridView];
}
// Since we are flipping the columns and the rows when we want this method call to flip them for us
-(IGCellPath *)normalizePath:(IGCellPath *)path
{
    return [IGCellPath pathForRow:path.columnIndex inSection:path.sectionIndex inColumn:path.rowIndex];
}
// And this reverses the change made in normalizePath.
-(IGCellPath *)deNormalizePath:(IGCellPath *)path
{
    return [IGCellPath pathForRow:path.columnIndex inSection:path.sectionIndex inColumn:path.rowIndex];
}
// in this case there are no titles for the header column, return an empty string.
-(NSString *)gridView:(IGGridView *)gridView titleForHeaderInColumn:(NSInteger)column
{
    return @"";
}

// We will use the fixed left column to hold the column headers now moved to be row headers.  So mark a single column as fixed.
-(NSInteger)numberOfFixedLeftColumnsInGridView:(IGGridView *)gridView
{
    return 1;
}

// When the fixed column cells are being rendered, we will want to take control of that process to show the row headers for the row.  We will put the column header text into the cell.
-(IGGridViewCell *)gridView:(IGGridView *)gridView fixedLeftCellAt:(IGCellPath *)path
{
    IGGridViewCell* c = [gridView dequeueReusableCellWithIdentifier:@"fc"];
    if (!c)
    {
        c= [[IGGridViewCell alloc]initWithReuseIdentifier:@"fc"];
    }
    NSString* columnHeader = ((IGGridViewColumnDefinition*) self.columns[path.rowIndex]).headerText;
    c.textLabel.text = columnHeader;
    c.backgroundColor = [UIColor greenColor];
    return c;
}

// We created a custom headerCell to show the image of the person whose data is being displayed.  Override this method to get the data
-(IGGridViewHeaderCell *)gridView:(IGGridView *)gridView headerCellAt:(NSInteger)column
{
    MyCustomHeaderCellWithImageCell* hc = [gridView dequeueReusableCellWithIdentifier:@"hc"];
    if(!hc)
    {
        hc =[[MyCustomHeaderCellWithImageCell alloc]initWithReuseIdentifier:@"hc"];
    }
    // Gets the "real" row of data from the data source
    IGCellPath* path = [IGCellPath pathForRow:0 inSection:0 inColumn:column];
    path = [self deNormalizePath:path];
    
    // then gets the data object
    igSalesmanItem* item = self.data[path.rowIndex];
    
    // and finds the image associated with that data object.
    hc.image = item.image;
    
    return hc;
}
@end
